MethodChannelMillimeters class

An implementation of MillimetersPlatform that uses method channels.

Inheritance

Constructors

MethodChannelMillimeters()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
resolution → Stream<Size>
no setterinherited
resolutionController → StreamController<Size>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Stream<Size>
no setterinherited
sizeController → StreamController<Size>
finalinherited

Methods

getPlatformVersion() → Future<String?>
override
getResolution() → Future<Size?>
override
getSize() → Future<Size?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited