MillimetersPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MillimetersPlatform
Implementers

Constructors

MillimetersPlatform({StreamController<Size>? resolution, StreamController<Size>? size})
Constructs a MillimetersPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
resolution → Stream<Size>
no setter
resolutionController → StreamController<Size>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Stream<Size>
no setter
sizeController → StreamController<Size>
final

Methods

getPlatformVersion() → Future<String?>
getResolution() → Future<Size?>
getSize() → Future<Size?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ MillimetersPlatform
The default instance of MillimetersPlatform to use.
getter/setter pair